﻿using HealthMonitor.Core.Cache;
using HealthMonitor.Core.Dal;
using HealthMonitor.Core.Operator;
using HealthMonitor.Service.Cache;
using HealthMonitor.Util.Entities.HealthMonitor;
using HealthMonitor.WebApi.Configs;
using HealthMonitor.WebApi.Controllers.Base;
using Microsoft.AspNetCore.Mvc;

namespace HealthMonitor.WebApi.Controllers.HealthMonitor
{
    [ApiExplorerSettings(GroupName = AppConsts.SWAGGER_DOC_HealthMonitor)]
    public class HmBloodPressReferenceValueController : HealthMonitorControllerBase<HmBloodPressReferenceValue>
    {
        private readonly BloodPressReferenceValueCacheManager _bpRefValCacheManager;
        public HmBloodPressReferenceValueController(
            IHealthMonitorDataAccessor dataAccessor,
            IHealthMonitorOperatorManager operatorManager,
            IDurableEntityManager durableManager,
            ILogger<HmBloodPressReferenceValueController> logger,
            BloodPressReferenceValueCacheManager bpRefValCacheManager
            )
            : base(dataAccessor, operatorManager, durableManager, logger)
        {

            _bpRefValCacheManager = bpRefValCacheManager;
        }

        [HttpPut]
        //[UpdateCacheInterceptor]
        public override async void Update([FromBody] HmBloodPressReferenceValue model, [FromHeader] string requestId)
        {
            AssertModelStateIsValid(model);
            _dataAccessor.Update(model);
            _dataAccessor.Save();
             await _bpRefValCacheManager.UpdateBloodPressReferenceValueAsync(model);
        }

        [HttpDelete]

        //[DeleteCacheInterceptor]
        public override async void Delete([FromBody] HmBloodPressReferenceValue model, [FromHeader] string requestId)
        {
            _dataAccessor.Delete(model);
            _dataAccessor.Save();
            await _bpRefValCacheManager.DeleteBloodPressReferenceValueAsync(model).ConfigureAwait(false);
          
        }
    }
}
